==> xcsoar-6.8.8.tar.xz: xcsoar-6.8.8/src/CrossSection/TerrainXSRenderer.hpp <==
/*
  Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2015 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef TERRAIN_CROSS_SECTION_RENDERER_HPP
#define TERRAIN_CROSS_SECTION_RENDERER_HPP

#include "Terrain/RasterBuffer.hpp"

class Canvas;
class ChartRenderer;
struct CrossSectionLook;
struct RasterPoint;

/**
 * A Window which renders a terrain and airspace cross-section
 */
class TerrainXSRenderer
{
  const CrossSectionLook &look;

public:
  TerrainXSRenderer(const CrossSectionLook &_look): look(_look) {}

  void Draw(Canvas &canvas, const ChartRenderer &chart,
            const short *elevations) const;

private:
  void DrawPolygon(Canvas &canvas, RasterBuffer::TerrainType type,
                   const RasterPoint *points, unsigned num_points) const;
};

#endif

==> xcsoar-7.9.tar.xz: xcsoar-7.9/src/CrossSection/TerrainXSRenderer.hpp <==
/*
  Copyright_License {

  XCSoar Glide Computer - http://www.xcsoar.org/
  Copyright (C) 2000-2021 The XCSoar Project
  A detailed list of copyright holders can be found in the file "AUTHORS".

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
}
*/

#ifndef TERRAIN_CROSS_SECTION_RENDERER_HPP
#define TERRAIN_CROSS_SECTION_RENDERER_HPP

#include "Terrain/Height.hpp"

class Canvas;
class ChartRenderer;
struct CrossSectionLook;
struct BulkPixelPoint;

/**
 * A Window which renders a terrain and airspace cross-section
 */
class TerrainXSRenderer
{
  const CrossSectionLook &look;

public:
  TerrainXSRenderer(const CrossSectionLook &_look): look(_look) {}

  void Draw(Canvas &canvas, const ChartRenderer &chart,
            const TerrainHeight *elevations) const;

private:
  void DrawPolygon(Canvas &canvas, TerrainType type,
                   const BulkPixelPoint *points, unsigned num_points) const;
};

#endif
